
About the Heron framework
=========================

Heron is an open source software conceived as an experiment (and general data) pipeline implementation
tool. It allows users to realise their conceptual experimental designs such that the final result, i.e. the implementation
running the experiment, visually and structurally bears a significant resemblance to its mental schema, i.e. the idea of
the experiment in the experimenter's imagination.

Heron combines a Node based experiment designer with a Python API allowing users to quicly construct and add their own
Nodes. It fully obfuscates the Node communication from the user and offers seamless communication between separate machines
running different operating systems.



